import { _document, DOCUMENT } from './document.service';
/* tslint:disable:no-unused-variable */
import { TestBed, inject } from '@angular/core/testing';
import { ClipboardService } from './clipboard.service';
import { WindowSrv } from './window.service';
describe('Service: Clipboard', function () {
    beforeEach(function () {
        TestBed.configureTestingModule({
            providers: [
                { provide: DOCUMENT, useFactory: _document },
                WindowSrv,
                ClipboardService
            ]
        });
    });
    it('should service work', inject([ClipboardService], function (service) {
        expect(service).toBeTruthy();
    }));
    it('it is supported', inject([ClipboardService], function (service) {
        expect(service.isSupported).toBeTruthy();
    }));
    describe('check if input is valid', function () {
        var /** @type {?} */ input;
        beforeEach(function () {
            input = document.createElement("input");
        });
        it('input is a valid target', inject([ClipboardService], function (service) {
            expect(service.isTargetValid(input)).toBeTruthy();
        }));
        it('input[disabled] is NOT a valid target', inject([ClipboardService], function (service) {
            input.setAttribute('disabled', '');
            expect(function () { return service.isTargetValid(input); })
                .toThrowError('Invalid "target" attribute. Please use "readonly" instead of "disabled" attribute');
        }));
    });
    describe('check if textarea is valid', function () {
        var /** @type {?} */ ta;
        beforeEach(function () {
            ta = document.createElement("textarea");
        });
        it('textarea is a valid target', inject([ClipboardService], function (service) {
            expect(service.isTargetValid(ta)).toBeTruthy();
        }));
        it('ta[disabled] is NOT a valid target', inject([ClipboardService], function (service) {
            ta.setAttribute('disabled', '');
            expect(function () { return service.isTargetValid(ta); })
                .toThrowError('Invalid "target" attribute. Please use "readonly" instead of "disabled" attribute');
        }));
    });
    describe('check if other html element is valid', function () {
        var /** @type {?} */ div = undefined;
        it('undefined is NOT a valid target', inject([ClipboardService], function (service) {
            expect(function () { return service.isTargetValid(div); })
                .toThrowError('Target should be input or textarea');
        }));
        it('div is NOT a valid target', inject([ClipboardService], function (service) {
            div = document.createElement("div");
            expect(function () { return service.isTargetValid(div); })
                .toThrowError('Target should be input or textarea');
        }));
    });
});
//# sourceMappingURL=clipboard.service.spec.js.map